/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *    XMMP - X MultiMedia Project					     *
 *    This Code is Copyright (c) 1999, 2000 by Arthur Kleer		     *
 *    All rights reserved.						     *
 *    								             *
 *    See COPYING in the main source dir for more details.		     *
 *								             *
 *    For contact, mail to: 'xmmp@frozenproductions.com'	             *
 *    Visit our Homepage: http://www.frozenproductions.com                   *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef INC_libxmm_h
#define INC_libxmm_h

/*
 * libxmm.h
 * Interface to X MultiMedia Library
 * You need to include this file, if you are coding applications using
 * this project.
 */

#include "config.h"
#include "version.h"
#include "klist.h"
#include "utils.h"
#include "xmmtypes.h"

/*
 * Return values:
 * All fuctions returning values, return -1 if they fail for some reason
 * Fuctions returning pointers, return NULL on failure.
 * An internal errorcode is set, an the error message can be obtained
 * using xmm_Error()
 */

//
// Prototypes
//

		/* Inititialize X MultiMedia Library */
int		xmm_Init( void );
		/* Free all resources */
void		xmm_Exit( void );

		/* Open file */
int		xmm_OpenFile( char *filename );
		/* Close file */
void		xmm_CloseFile( void );

		/* Set output plugins, which will be used */
int		xmm_SetOutputPlugins( char *graph_plugin, char *sound_plugin );

// Gtk wins
		/* Get configuration, info and about dialog ( Gtk, mplayer ) */
int		xmm_InputGtkWin( int win );

// Play control

int		xmm_Play( void );
int		xmm_Pause( void );
int		xmm_Stop( void );
int		xmm_Seek( int value );
int		xmm_Loop( int flag );	// Not implemented in all plugins
					// Do we need such a function ?

// Size
		/* Scale the video output, see xmmtypes.h for special values */
int		xmm_Scale( int width, int height );

// Status

		/* Get detailed information about video, audio */
double		xmm_GetInfo( XMM_Info *xmm_info, char **name, double *playtime, double *seekval );
		/* Get playstatus of the file */
int		xmm_GetStatus( void );

// Volume

int		xmm_SetVolume( int left, int right );
int		xmm_GetVolume( int *left, int *right );

//
// Plugin
//

/*
 * Only needed for getting plugin lists, registering plugins
 * from data and manually
 */

void		*xmm_PluginRegister( char *filename );
void		*xmm_PluginRegisterX( char *filename, int type );
XMM_Plugin	*xmm_PluginRegisterFromData( XMM_Plugin *plugin );
KList		*xmm_PluginScanDir( char *dirname, int type );
void		xmm_PluginRemove( void *info );
void		xmm_PluginRemoveList( KList *list );

//
// Filters
//

		/* adds filter plugins */
int		xmm_FilterAddList( KList *_pFilterList );

		/* remove all filter plugins from list */
int		xmm_FilterRemoveAll( void );

//
// Error handling
//

		/* get string of last error */
char		*xmm_Error( void );

#endif
