/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *    XMMP - X MultiMedia Project					     *
 *    This Code is Copyright (c) 1999, 2000 by Arthur Kleer		     *
 *    All rights reserved.						     *
 *    								             *
 *    See COPYING in the main source dir for more details.		     *
 *								             *
 *    For contact, mail to: 'xmmp@frozenproductions.com'	             *
 *    Visit our Homepage: http://www.frozenproductions.com                   *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef INC_xmmp_h
#define	INC_xmmp_h

/*
 * xmmp.h
 * Needed if you want to code a plugin
 */

#include "xmmtypes.h"
#include "config.h"
#include "version.h"
#include "klist.h"
#include "utils.h"

// *
// * * * * Definitions
// *

//
// Graph
//

#define XMM_SURFACE_TYPE_RAW	1
#define XMM_SURFACE_TYPE_X11	2
#define XMM_SURFACE_TYPE_SDL	3

#define	XMM_RESIZE_DO		1
#define	XMM_RESIZE_QUERY	2

//
// Codec
//

#define	XMM_CODEC_MODE_DECODE	0x01
#define	XMM_CODEC_MODE_ENCODE	0x02
#define	XMM_CODEC_MODE_QUERY	0x80

#define	XMM_CODEC_FORMAT_WAV	1
#define	XMM_CODEC_FORMAT_AVI	2

//
// Error codes
//

#define XMM_ERR_SOUND_NULL	1
#define XMM_ERR_SOUND_INIT	2
#define XMM_ERR_SOUND_START	3
#define XMM_ERR_SOUND_MIXER	4

#define XMM_ERR_GRAPH_NULL	5
#define XMM_ERR_GRAPH_INIT	6
#define XMM_ERR_GRAPH_START	7
#define XMM_ERR_GRAPH_RESIZE	8

#define XMM_ERR_CODEC_INIT	9
#define XMM_ERR_CODEC_PROC	10

#define XMM_ERR_INPUT_INIT	11
#define XMM_ERR_INPUT_OPEN	12

#define XMM_ERR_NOTEXT		13
#define XMM_ERR_UNKOWN		14
#define	XMM_ERR_ALLOC		15

// *
// * * * Types
// *

/*
 * Needed for WAudioCodec Fuctions
 */

#ifndef _WAVEFORMATEX_
#define _WAVEFORMATEX_

typedef struct _WAVEFORMATEX
{
    WORD	wFormatTag;		// Format
    WORD	nChannels;		// Channels
    DWORD	nSamplesPerSec;		// Rate
    DWORD	nAvgBytesPerSec;	// Average bytes / sec
    WORD	nBlockAlign;		// block size of data
    WORD	wBitsPerSample;		// Number of bits per sample
    WORD	cbSize;			// Size of extra data
} WAVEFORMATEX;

#endif

// *
// * * * Prototypes
// *

/* Get current graph plugin. Can be used in visualization plugins,
 * to get plugin, that was set by user */
XMM_PluginGraph	*xmm_GetPluginGraph( void );

/* Get opened file. Can be used in output plugins to build write file name */
char *xmm_GetOpenFile( void );

//
// Filter
//

/* Menage filters, needs to be called in Sound Output Start() */
int xmm_FilterSetPref( int SampRate, int Channels, int BPS );

/* Menage filters, needs to be called in Sound Output Write() */
int xmm_FilterDo( void *data, int count );

//
// Errors
//

/* Set error code and string */
int xmm_SetErrno( int error, const char *format, ... );

//
// Stream fuctions
//

XMM_STREAM *xmm_StreamOpen( char *filename, char *mode );
int xmm_StreamClose( XMM_STREAM *stream );
int xmm_StreamRead( void *ptr, int size, int nmemb, XMM_STREAM *stream );
int xmm_StreamWrite( void *ptr, int size, int nmemb, XMM_STREAM *stream );
int xmm_StreamTell( XMM_STREAM *stream );
int xmm_StreamSeek( XMM_STREAM *stream, long offset, int whence );
int xmm_StreamEOF( XMM_STREAM *stream );

//
// Codec stuff
//

XMM_PluginCodec *xmm_OpenCodec( int format, DWORD codec, int mode, void *header, void *extra );
void xmm_CloseCodec( XMM_PluginCodec *codec );

//
// W32 Codec stuff
//

int xmm_OpenWVideoCodec( int mode, void *stream_format_header );
int xmm_CloseWVideoCodec( void );
int xmm_CheckWVideoCodec( int mode, void *stream_format_header );
int xmm_ProcWVideoCodec( char *source, char *dest, int keyframe, int size );

int xmm_OpenWAudioCodec( int mode, WAVEFORMATEX *wf_head, void **extra );
void xmm_CloseWAudioCodec( void );
int xmm_CheckWAudioCodec( int mode, WAVEFORMATEX *wf_head, void **extra );

#endif
