/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *    XMMP - X MultiMedia Project					     *
 *    This Code is Copyright (c) 1999, 2000 by Arthur Kleer		     *
 *    All rights reserved.						     *
 *    								             *
 *    See COPYING in the main source dir for more details.		     *
 *								             *
 *    For contact, mail to: 'xmmp@frozenproductions.com'	             *
 *    Visit our Homepage: http://www.frozenproductions.com                   *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef INC_xmmtypes_h
#define INC_xmmtypes_h

#include <stdio.h>

//
// Basic Types
//

#ifndef __WINE_WINDEF_H

//typedef unsigned char	BYTE;
typedef unsigned short	WORD;
typedef unsigned long	DWORD;

#endif

//
// Definitions
//

#define	XMM_PLUGIN_ID		"XMMP"
#define	XMM_MAXPATHLEN		256

//
// Input status
//

#define	XMM_STOPPED		1
#define	XMM_PLAYING		2
#define	XMM_PAUSED		4
#define	XMM_ERROR		8

//
// Plugin Types
//

#define	XMM_PLUGIN_TYPE_INPUT	1
#define	XMM_PLUGIN_TYPE_GRAPH	2
#define	XMM_PLUGIN_TYPE_SOUND	3
#define	XMM_PLUGIN_TYPE_CODEC	4
#define	XMM_PLUGIN_TYPE_VIS	5

//
// Time calculations
//

#define	TIME_H( sec )	((int) sec / 3600 )
#define	TIME_M( sec )	((int) (( sec - TIME_H( sec ) * 3600 ) / 60 ))
#define	TIME_S( sec )	((int) ( sec - TIME_H( sec ) * 3600 - TIME_M( sec ) * 60 ))
#define TIME_T( sec )	((int) ( sec - TIME_H( sec ) * 3600 - TIME_M( sec ) * 60  - TIME_S( sec )))

//
// Graph
//

/* Special values for xmm_Scale() */
#define	XMM_SCALE_ORIG		-1
#define	XMM_SCALE_DOUBLE	-2
#define	XMM_SCALE_FULL		-3

/* Key modes for the keyevent callback */
#define	XMM_KEY_PRESSED		1
#define	XMM_KEY_RELEASED	2

//
// Gtk windows, argument to xmm_InputGtkWin()
//

#define	XMM_GTKWIN_ABOUT	1
#define	XMM_GTKWIN_INFO		2
#define	XMM_GTKWIN_CONFIG	3

//
// Types
//

/*
 *  Video info struct
 */

typedef struct _xmm_VideoInfo
{
// Static
    WORD	Width;
    WORD	Height;
    DWORD	TotalSize;
    double	TotalTime;
// Dynamic
    DWORD	cFrame;
    double	cFPS;
} XMM_VideoInfo;

/*
 *  Audio info struct
 */

typedef struct _xmm_AudioInfo
{
    WORD	BitRate;
    WORD	SampleRate;
    WORD	Channels;
} XMM_AudioInfo;

/*
 * Info struct, filled by xmm_GetInfo()
 */

typedef struct _xmm_Info
{
    int			hasVideo;
    XMM_VideoInfo	vi;
    int			hasAudio;
    XMM_AudioInfo	ai;
} XMM_Info;

/*
 *
 */

typedef struct _xmm_stream
{
    FILE *stream;
} XMM_STREAM;

//
// Plugins
//

struct _xmm_plugin;

/*
 * Each Plugin may provide one or more of these (Gtk)Dialogues
 */

typedef struct _xmm_GtkStuff
{
    void	(*about)( void );
    int		(*config)( void );
    void	(*info)( struct _xmm_plugin *plugin );
} XMM_GtkStuff;

/*
 * Plugin struct, common to all plugin types
 */

typedef struct _xmm_plugin
{
    void		*Handle;
    char		ID[4];
    WORD		Type;
    WORD		Flags;
    DWORD		Version;

    char		Filename[256];
    char		Name[32];
    char		Desc[96];
    char		Copy[96];

    void		*priv;

    XMM_GtkStuff	gtk;

} XMM_Plugin;

/*
 * Plugin struct, for ( Graph ) Output Plugins
 */

typedef struct _xmm_PluginGraph
{
    XMM_Plugin			sys;
    struct _xmm_PluginGraph *	(*Init)( int (*winEventProc)( int key, int mode ));
    void			(*Exit)( struct _xmm_PluginGraph *graph );
    int				(*Start)( struct _xmm_PluginGraph *graph, int width, int height );
    void			(*Blit)( struct _xmm_PluginGraph *graph, char *img, int x, int y, WORD width, WORD height );
    int				(*Resize)( struct _xmm_PluginGraph *graph, int mode, int width, int height );
    void *			(*GetSurface)( struct _xmm_PluginGraph *graph, int *type );
} XMM_PluginGraph;

/*
 * Plugin struct, for ( Sound ) Output Plugins
 */

typedef struct _xmm_PluginSound
{
    XMM_Plugin			sys;
    struct _xmm_PluginSound *	(*Init)( void );
    void			(*Exit)( struct _xmm_PluginSound *sound );
    int				(*Start)( struct _xmm_PluginSound *sound, int SampRate, int Channels, int BPS );
    int				(*Write)( struct _xmm_PluginSound *sound, void *data, int count );
    int				(*SetVolume)( struct _xmm_PluginSound *sound, int left, int right );
    int				(*GetVolume)( struct _xmm_PluginSound *sound, int *left, int *right );
} XMM_PluginSound;

/*
 * Plugins struct, for Input Plugins
 */

typedef struct _xmm_PluginInput
{
    XMM_Plugin			sys;
    struct _xmm_PluginInput *	(*Init)( XMM_PluginGraph *graph, XMM_PluginSound *sound, int (*winEventProc)( int key, int mode ));
    int				(*CheckFile)( char *filename );
    int				(*Open)( struct _xmm_PluginInput *input, char *filename, int Sound );
    void			(*Close)( struct _xmm_PluginInput *input );
    void			(*Play)( struct _xmm_PluginInput *input );
    void			(*Stop)( struct _xmm_PluginInput *input );
    void			(*Pause)( struct _xmm_PluginInput *input );
    int				(*GetStatus)( struct _xmm_PluginInput *input );
    void			(*Loop)( struct _xmm_PluginInput *input, int flag );
    void			(*Seek)( struct _xmm_PluginInput *input, float seek );
    void			(*Rewind)( struct _xmm_PluginInput *input );
    void			(*Skip)( struct _xmm_PluginInput *input, float seconds );
    int				(*SetVolume)( struct _xmm_PluginInput *sound, int left, int right );
    int				(*GetVolume)( struct _xmm_PluginInput *sound, int *left, int *right );
    double			(*GetInfo)( struct _xmm_PluginInput *input, XMM_Info *xmm_info, char **name, double *playtime, double *seekval );
    void			(*Scale)( struct _xmm_PluginInput *input, int width, int height );
} XMM_PluginInput;

/*
 * Plugins struct, for Codec Plugins
 */

typedef struct _xmm_PluginCodec
{
    XMM_Plugin			sys;
    struct _xmm_PluginCodec *	(*Init)( int format, DWORD codec, int mode, void *header, void **extra );
    void			(*Exit)( struct _xmm_PluginCodec *codec );
    int				(*Proc)( struct _xmm_PluginCodec *codec, char *buffer, int size, XMM_STREAM *stream );
} XMM_PluginCodec;

/*
 * Plugins struct, for Filter Plugins
 */

typedef struct _xmm_PluginFilter
{
    XMM_Plugin			sys;
    struct _xmm_PluginFilter *	(*Init)( int SampRate, int Channels, int BPS );
    void			(*Exit)( struct _xmm_PluginFilter *filter );
    int				(*Proc)( struct _xmm_PluginFilter *filter, char *buffer, int size );
} XMM_PluginFilter;

#endif
